diff --git a/doc/src/api/vprinternals/router_heap.rst b/doc/src/api/vprinternals/router_heap.rst
index 39cbaa13b36..cb652811e6c 100644
--- a/doc/src/api/vprinternals/router_heap.rst
+++ b/doc/src/api/vprinternals/router_heap.rst
@@ -24,10 +24,8 @@ KAryHeap
----------
.. doxygenclass:: KAryHeap
:project: vpr
- :members:
FourAryHeap
----------
.. doxygenclass:: FourAryHeap
- :project: vpr
- :members:
\ No newline at end of file
+ :project: vpr
\ No newline at end of file
diff --git a/vpr/src/route/heap_type.h b/vpr/src/route/heap_type.h
index 8e446a151bd..76c0b956404 100644
--- a/vpr/src/route/heap_type.h
+++ b/vpr/src/route/heap_type.h
@@ -27,32 +27,29 @@ struct t_heap {
t_heap_path* path_data;
/**
- * @brief Get u.next.
+ * @brief Get the next t_heap item in the linked list.
*/
t_heap* next_heap_item() const {
return u.next;
}
/**
- * @brief Set u.next.
+ * @brief Set the next t_heap item in the linked list.
*/
void set_next_heap_item(t_heap* next) {
u.next = next;
}
/**
- * @brief Get u.prev_edge.
+ * @brief Get the edge from the previous node used to reach the current node.
*
* @note
* Be careful: will return 0 (a valid id!) if uninitialized.
- */
- constexpr RREdgeId prev_edge() const {
- static_assert(sizeof(uint32_t) == sizeof(RREdgeId));
- return RREdgeId(u.prev_edge);
+ @@ -52,7 +52,7 @@ struct t_heap {
}
/**
- * @brief Set u.prev_edge.
+ * @brief Set the edge from the previous node used to reach the current node..
*/
inline void set_prev_edge(RREdgeId edge) {
static_assert(sizeof(uint32_t) == sizeof(RREdgeId));
@@ -61,7 +58,7 @@ struct t_heap {
private:
union {
///@brief Pointer to the next s_heap structure in the free linked list.
t_heap* next = nullptr;
/**
@@ -121,7 +118,7 @@ class HeapStorage {
* As a general rule, any t_heap objects returned from this interface,
* **must** be HeapInterface::free'd before destroying the HeapInterface
* instance. This ensure that no leaks are present in the users of the heap.
- * Violating this assumption may result in a assertion violation.
+ * Violating this assumption may result in an assertion violation.
*/
class HeapInterface {
public:
@@ -160,7 +157,7 @@ class HeapInterface {
* - empty_heap
* - build_heap
*
- * @param grid
+ * @param grid The FPGA device grid
*/
virtual void init_heap(const DeviceGrid& grid) = 0;
@@ -61,7 +58,7 @@ struct t_heap {
private:
union {
- ///@brief Pointer to the next s_heap structure in the free linked list.
+ ///@brief Pointer to the next t_heap structure in the free linked list.
t_heap* next = nullptr;
/**